@@ -73,14 +73,17 @@ class RequestMessage:
     request_id: int = field(default_factory=lambda: get_next_int(10000, 32767))
 
     def encode_message(
-        self, protocol: RoborockMessageProtocol, security_data: SecurityData | None = None, version: str = "1.0"
+        self,
+        protocol: RoborockMessageProtocol,
+        security_data: SecurityData | None = None,
+        version: LocalProtocolVersion = LocalProtocolVersion.V1,
     ) -> RoborockMessage:
         """Convert the request message to a RoborockMessage."""
         return RoborockMessage(
             timestamp=self.timestamp,
             protocol=protocol,
             payload=self._as_payload(security_data=security_data),
-            version=version.encode(),
+            version=version.value.encode(),
         )
 
     def _as_payload(self, security_data: SecurityData | None) -> bytes:
@@ -155,7 +158,7 @@ def decode_rpc_response(message: RoborockMessage) -> ResponseMessage:
     exc: RoborockException | None = None
     if error := data_point_response.get("error"):
         exc = RoborockException(error)
-    if not (result := data_point_response.get("result")):
+    if (result := data_point_response.get("result")) is None:
         exc = RoborockException(f"Invalid V1 message format: missing 'result' in data point for {message.payload!r}")
     else:
         _LOGGER.debug("Decoded V1 message result: %s", result)
